==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/QUOTATIONLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour QUOTATIONLINEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="QUOTATIONLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONRESPONSEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUOTATIONLINEID_Type", propOrder = {
    "quotationresponseid",
    "quotationlinenum"
})
public class QUOTATIONLINEID_Type {

    @XmlElement(name = "QUOTATIONRESPONSEID", required = true)
    protected QUOTATIONRESPONSEID_Type quotationresponseid;
    @XmlElement(name = "QUOTATIONLINENUM")
    protected long quotationlinenum;

    /**
     * Obtient la valeur de la propriété quotationresponseid.
     * 
     * @return
     *     possible object is
     *     {@link QUOTATIONRESPONSEID_Type }
     *     
     */
    public QUOTATIONRESPONSEID_Type getQUOTATIONRESPONSEID() {
        return quotationresponseid;
    }

    /**
     * Définit la valeur de la propriété quotationresponseid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUOTATIONRESPONSEID_Type }
     *     
     */
    public void setQUOTATIONRESPONSEID(QUOTATIONRESPONSEID_Type value) {
        this.quotationresponseid = value;
    }

    /**
     * Obtient la valeur de la propriété quotationlinenum.
     * 
     */
    public long getQUOTATIONLINENUM() {
        return quotationlinenum;
    }

    /**
     * Définit la valeur de la propriété quotationlinenum.
     * 
     */
    public void setQUOTATIONLINENUM(long value) {
        this.quotationlinenum = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/QUOTATIONLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for QUOTATIONLINEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="QUOTATIONLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONRESPONSEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUOTATIONLINEID_Type", propOrder = {
    "quotationresponseid",
    "quotationlinenum"
})
public class QUOTATIONLINEID_Type {

    @XmlElement(name = "QUOTATIONRESPONSEID", required = true)
    protected QUOTATIONRESPONSEID_Type quotationresponseid;
    @XmlElement(name = "QUOTATIONLINENUM")
    protected long quotationlinenum;

    /**
     * Gets the value of the quotationresponseid property.
     * 
     * @return
     *     possible object is
     *     {@link QUOTATIONRESPONSEID_Type }
     *     
     */
    public QUOTATIONRESPONSEID_Type getQUOTATIONRESPONSEID() {
        return quotationresponseid;
    }

    /**
     * Sets the value of the quotationresponseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUOTATIONRESPONSEID_Type }
     *     
     */
    public void setQUOTATIONRESPONSEID(QUOTATIONRESPONSEID_Type value) {
        this.quotationresponseid = value;
    }

    /**
     * Gets the value of the quotationlinenum property.
     * 
     */
    public long getQUOTATIONLINENUM() {
        return quotationlinenum;
    }

    /**
     * Sets the value of the quotationlinenum property.
     * 
     */
    public void setQUOTATIONLINENUM(long value) {
        this.quotationlinenum = value;
    }

}
